Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(527)

Unified Diff: components/autofill/core/browser/autofill_metrics.h

Issue 2575263002: [Autofill] Add a new metric for upstream. (Closed)
Patch Set: Added all the unit tests. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/autofill_metrics.h
diff --git a/components/autofill/core/browser/autofill_metrics.h b/components/autofill/core/browser/autofill_metrics.h
index b8e569baf697decbc73e158ec4996a1c81f7f1db..557d28ac040bbeeca9932daa7e3647ff0f895c1d 100644
--- a/components/autofill/core/browser/autofill_metrics.h
+++ b/components/autofill/core/browser/autofill_metrics.h
@@ -363,9 +363,10 @@ class AutofillMetrics {
FORM_EVENT_SERVER_SUGGESTION_FILLED_ONCE,
FORM_EVENT_MASKED_SERVER_CARD_SUGGESTION_FILLED_ONCE,
// A form was submitted. Depending on the user filling a local, server,
- // masked server card or no suggestion one of the following will be
- // triggered. Only one of the following four will be triggered per page
- // load.
+ // masked server card or suggestion shown or no suggestion filled one of the
+ // following will be triggered. Only one of the following four will be
+ // triggered per page load.
+ FORM_EVENT_SUGGESTION_SHOWN_SUBMITTED_ONCE,
Jared Saul 2016/12/15 21:30:26 FORM_EVENT_SUGGESTION_SHOWN_SUBMITTED_ONCE shouldn
Shanfeng 2016/12/15 21:59:03 Done.
FORM_EVENT_NO_SUGGESTION_SUBMITTED_ONCE,
FORM_EVENT_LOCAL_SUGGESTION_SUBMITTED_ONCE,
FORM_EVENT_SERVER_SUGGESTION_SUBMITTED_ONCE,
@@ -377,8 +378,9 @@ class AutofillMetrics {
// An autofillable form is about to be submitted. If the submission is not
// interrupted by JavaScript, the "form submitted" events above will also be
// logged. Depending on the user filling a local, server, masked server card
- // or no suggestion one of the following will be triggered, at most once per
- // page load.
+ // or suggestion shown or no suggestion filled one of the following will be
+ // triggered, at most once per page load.
+ FORM_EVENT_SUGGESTION_SHOWN_WILL_SUBMIT_ONCE,
Jared Saul 2016/12/15 21:30:26 ditto
Shanfeng 2016/12/15 21:59:03 Done.
FORM_EVENT_NO_SUGGESTION_WILL_SUBMIT_ONCE,
FORM_EVENT_LOCAL_SUGGESTION_WILL_SUBMIT_ONCE,
FORM_EVENT_SERVER_SUGGESTION_WILL_SUBMIT_ONCE,
« no previous file with comments | « no previous file | components/autofill/core/browser/autofill_metrics.cc » ('j') | tools/metrics/histograms/histograms.xml » ('J')

Powered by Google App Engine
This is Rietveld 408576698